@@ -83,10 +83,11 @@ enum [[deprecated]] : int {
     SBK_QTQUICK3D_QLIST_QQUICK3DOBJECTPTR_IDX                = 2, // QList<QQuick3DObject*>
     SBK_QTQUICK3D_QLIST_QOBJECTPTR_IDX                       = 4, // QList<QObject*>
     SBK_QTQUICK3D_QLIST_QBYTEARRAY_IDX                       = 6, // QList<QByteArray>
-    SBK_QTQUICK3D_QLIST_QVARIANT_IDX                         = 8, // QList<QVariant>
-    SBK_QTQUICK3D_QLIST_QSTRING_IDX                          = 10, // QList<QString>
-    SBK_QTQUICK3D_QMAP_QSTRING_QVARIANT_IDX                  = 12, // QMap<QString,QVariant>
-    SBK_QTQUICK3D_CONVERTERS_IDX_COUNT                       = 14,
+    SBK_QTQUICK3D_STD_PAIR_QBYTEARRAY_INT_IDX                = 8, // std::pair<QByteArray,int>
+    SBK_QTQUICK3D_QLIST_QVARIANT_IDX                         = 10, // QList<QVariant>
+    SBK_QTQUICK3D_QLIST_QSTRING_IDX                          = 12, // QList<QString>
+    SBK_QTQUICK3D_QMAP_QSTRING_QVARIANT_IDX                  = 14, // QMap<QString,QVariant>
+    SBK_QTQUICK3D_CONVERTERS_IDX_COUNT                       = 16,
 };
 
 // Converter indices
@@ -95,10 +96,11 @@ enum : int {
     SBK_QtQuick3D_QList_QQuick3DObjectPTR_IDX                = 1, // QList<QQuick3DObject*>
     SBK_QtQuick3D_QList_QObjectPTR_IDX                       = 2, // QList<QObject*>
     SBK_QtQuick3D_QList_QByteArray_IDX                       = 3, // QList<QByteArray>
-    SBK_QtQuick3D_QList_QVariant_IDX                         = 4, // QList<QVariant>
-    SBK_QtQuick3D_QList_QString_IDX                          = 5, // QList<QString>
-    SBK_QtQuick3D_QMap_QString_QVariant_IDX                  = 6, // QMap<QString,QVariant>
-    SBK_QtQuick3D_CONVERTERS_IDX_COUNT                       = 7,
+    SBK_QtQuick3D_std_pair_QByteArray_int_IDX                = 4, // std::pair<QByteArray,int>
+    SBK_QtQuick3D_QList_QVariant_IDX                         = 5, // QList<QVariant>
+    SBK_QtQuick3D_QList_QString_IDX                          = 6, // QList<QString>
+    SBK_QtQuick3D_QMap_QString_QVariant_IDX                  = 7, // QMap<QString,QVariant>
+    SBK_QtQuick3D_CONVERTERS_IDX_COUNT                       = 8,
 };
 // Macros for type check
 
