@@ -1,12 +1,15 @@
 import os
 import sys
 from pathlib import Path
-from textwrap import dedent
+from types import ModuleType
+# mypy: disable-error-code="name-defined"
 
 # __all__ is computed below.
 __pre_all__ = ["QtCore", "QtGui", "QtWidgets", "QtPrintSupport", "QtSql", "QtNetwork", "QtTest", "QtConcurrent", "QtDesigner", "QtXml", "QtHelp", "QtMultimedia", "QtMultimediaWidgets", "QtOpenGL", "QtOpenGLWidgets", "QtPositioning", "QtLocation", "QtNetworkAuth", "QtNfc", "QtQml", "QtQuick", "QtQuick3D", "QtQuickControls2", "QtQuickTest", "QtQuickWidgets", "QtRemoteObjects", "QtScxml", "QtSensors", "QtSerialPort", "QtSerialBus", "QtStateMachine", "QtTextToSpeech", "QtCharts", "QtSpatialAudio", "QtSvg", "QtSvgWidgets", "QtDataVisualization", "QtGraphs", "QtGraphsWidgets", "QtBluetooth", "QtUiTools", "QtAxContainer", "QtWebChannel", "QtWebSockets", "QtHttpServer", "Qt3DCore", "Qt3DRender", "Qt3DInput", "Qt3DLogic", "Qt3DAnimation", "Qt3DExtras"]
-__version__ = "6.8.0.2"
-__version_info__ = (6, 8, 0.2, "", "")
+__version__ = "6.8.1.1"
+__version_info__ = (6, 8, 1.1, "", "")
+
+SKIP_MYPY_TEST = bool("")
 
 
 def _additional_dll_directories(package_dir):
@@ -16,7 +19,7 @@ def _additional_dll_directories(package_dir):
     if root.suffix == '.zip':
         return []
     shiboken6 = root / 'shiboken6'
-    if shiboken6.is_dir(): # Standard case, only shiboken6 is needed
+    if shiboken6.is_dir():  # Standard case, only shiboken6 is needed
         return [shiboken6]
     # The below code is for the build process when generate_pyi.py
     # is executed in the build directory. We need libpyside and Qt in addition.
@@ -29,9 +32,9 @@ def _additional_dll_directories(package_dir):
         result.append(libpysideqml)
     for path in os.environ.get('PATH').split(';'):
         if path:
-             if (Path(path) / 'qmake.exe').exists():
-                 result.append(path)
-                 break
+            if (Path(path) / 'qmake.exe').exists():
+                result.append(path)
+                break
     return result
 
 
@@ -59,6 +62,7 @@ def _setupQtDirectories():
     try:
         # PYSIDE-1497: we use the build dir or install dir or site-packages, whatever the path
         #              setting dictates. There is no longer a difference in path structure.
+        global Shiboken
         from shiboken6 import Shiboken
     except Exception:
         paths = ', '.join(sys.path)
@@ -120,4 +124,18 @@ def __getattr__(name: str) -> list[str]:
     raise AttributeError(f"module '{__name__}' has no attribute '{name}' :)")
 
 
+# Be prepared that people can access the module dict instead.
+class ModuleDict(dict):
+    def __missing__(self, key):
+        if key == "__all__":
+            self[key] = __all__ if "__all__" in globals() else __getattr__("__all__")
+            return __all__
+        raise KeyError(f"dict of module '{__name__}' has no key '{key}' :)")
+
+
+class SubModule(ModuleType):
+    pass
+
+
 _setupQtDirectories()
+Shiboken.replaceModuleDict(sys.modules["PySide6"], SubModule, ModuleDict(globals()))
